@@ -52,8 +52,8 @@ plot(mod2)
 ###################################################
 ### code chunk number 8: SDEs.Rnw:225-229
 ###################################################
-mod1 <- snssde1d(drift=f,diffusion=g,x0=10,M=100,N=1000)
-mod2 <- snssde1d(drift=f,diffusion=g,x0=10,M=100,N=1000,type="str")
+mod1 <- snssde1d(drift=f,diffusion=g,x0=10,M=50,N=1000)
+mod2 <- snssde1d(drift=f,diffusion=g,x0=10,M=50,N=1000,type="str")
 summary(mod1)
 summary(mod2)
 
@@ -101,58 +101,61 @@ legend("topleft",c("mean path",paste("bound of", 95,"% confidence")),
 
 
 ###################################################
-### code chunk number 12: SDEs.Rnw:280-286
-###################################################
-a = 0.5; b=1; sigma=0.1
-fx <- expression( -( a*sin(x)+2*b*sin(2*x) ) )
-gx <- expression( sigma )
-mod <- snssde1d(drift=fx,diffusion=gx, x0=5, M=100, N=1000,Dt=0.002, method="rk3")
-mod
-summary(mod)
-
-
-###################################################
-### code chunk number 13: SDEs.Rnw:288-289 (eval = FALSE)
-###################################################
-## plot(mod,plot.type="single")
-
-
-###################################################
-### code chunk number 14: SDEs.Rnw:295-301
-###################################################
-plot(mod,plot.type="single")
-lines(time(mod),mean(mod),col=2,lwd=2)
-lines(time(mod),bconfint(mod,level=0.95)[,1],col=4,lwd=2)
-lines(time(mod),bconfint(mod,level=0.95)[,2],col=4,lwd=2)
-legend("topleft",c("mean path",paste("bound of", 95,"% confidence")),
-       inset = .01,col=c(2,4),lwd=2,cex=0.8)
-
-
-###################################################
-### code chunk number 15: SDEs.Rnw:335-341
+### code chunk number 12: SDEs.Rnw:302-308
 ###################################################
 K = 4; s = 1; sigma = 0.2
 fx <- expression( ((0.5*sigma^2 *x^(s-1) - K)/ x^s) )
 gx <- expression( sigma )
-mod <- snssde1d(drift=fx,diffusion=gx, x0=3, M=100, N=1000)
+mod <- snssde1d(drift=fx,diffusion=gx, x0=3, M=50, N=1000)
 mod
 summary(mod)
 
 
 ###################################################
-### code chunk number 16: SDEs.Rnw:343-344 (eval = FALSE)
+### code chunk number 13: SDEs.Rnw:310-311 (eval = FALSE)
 ###################################################
 ## plot(mod,plot.type="single")
 
 
 ###################################################
-### code chunk number 17: SDEs.Rnw:349-350
+### code chunk number 14: SDEs.Rnw:316-317
 ###################################################
 plot(mod,plot.type="single")
 
 
 ###################################################
-### code chunk number 18: SDEs.Rnw:428-437
+### code chunk number 15: SDEs.Rnw:392-399
+###################################################
+fx  <- expression(4*(-1-x)*y)
+gx  <- expression(0.2)
+fy  <- expression(4*(1-y)*x)
+gy  <- expression(0.2)
+mod2d <- snssde2d(driftx=fx,diffx=gx,drifty=fy,diffy=gy,x0=1,y0=-1,M=50,
+                  Dt=0.001,method="rk3")
+mod2d
+
+
+###################################################
+### code chunk number 16: SDEs.Rnw:402-404 (eval = FALSE)
+###################################################
+## plot(mod2d,pos=2)
+## plot2d(mod2d)
+
+
+###################################################
+### code chunk number 17: SDEs.Rnw:409-410
+###################################################
+plot(mod2d,pos=2)
+
+
+###################################################
+### code chunk number 18: SDEs.Rnw:412-413
+###################################################
+plot2d(mod2d)
+
+
+###################################################
+### code chunk number 19: SDEs.Rnw:431-440
 ###################################################
 a1  <- function(t) 2*t
 a2  <- function(t) 0.5*t
@@ -161,77 +164,69 @@ fx    <- expression(a1(t)*x)
 gx    <- expression(b1(t))
 fy    <- expression(a2(t)*x)
 gy    <- expression(b2(t))
-mod2d <- snssde2d(driftx=fx,diffx=gx,drifty=fy,diffy=gy,N=1000)
+mod2d <- snssde2d(driftx=fx,diffx=gx,drifty=fy,diffy=gy)
 mod2d
 
 
 ###################################################
-### code chunk number 19: SDEs.Rnw:440-442 (eval = FALSE)
+### code chunk number 20: SDEs.Rnw:443-444 (eval = FALSE)
 ###################################################
-## plot(mod2d,plot.type="single")
-## plot(mod2d)
+## plot(mod2d,union=TRUE,pos=3)
 
 
 ###################################################
-### code chunk number 20: SDEs.Rnw:447-448
+### code chunk number 21: SDEs.Rnw:449-450
 ###################################################
-plot(mod2d,plot.type="single")
+plot(mod2d,union=TRUE,pos=3)
 
 
 ###################################################
-### code chunk number 21: SDEs.Rnw:450-451
-###################################################
-plot(mod2d)
-
-
-###################################################
-### code chunk number 22: SDEs.Rnw:512-520
+### code chunk number 22: SDEs.Rnw:481-488
 ###################################################
 mu = 4; sigma=0.1
 fx <- expression( y )
 gx <- expression( 0 )
 fy <- expression( (mu*( 1-x^2 )* y - x) )
 gy <- expression( 2*sigma)
-mod2d <- snssde2d(driftx=fx,diffx=gx,drifty=fy,diffy=gy,N=10000,Dt=0.01,
-                  type="str")
+mod2d <- snssde2d(driftx=fx,diffx=gx,drifty=fy,diffy=gy,type="str",T=100,N=10000)
 mod2d
 
 
 ###################################################
-### code chunk number 23: SDEs.Rnw:523-525 (eval = FALSE)
+### code chunk number 23: SDEs.Rnw:491-493 (eval = FALSE)
 ###################################################
-## plot2d(mod2d,type="l")
-## plot(mod2d)
+## plot2d(mod2d)
+## plot(mod2d,pos=3)
 
 
 ###################################################
-### code chunk number 24: SDEs.Rnw:530-531
+### code chunk number 24: SDEs.Rnw:498-499
 ###################################################
-plot2d(mod2d,type="l")
+plot2d(mod2d)
 
 
 ###################################################
-### code chunk number 25: SDEs.Rnw:533-534
+### code chunk number 25: SDEs.Rnw:501-502
 ###################################################
-plot(mod2d)
+plot(mod2d,pos=3)
 
 
 ###################################################
-### code chunk number 26: SDEs.Rnw:542-545
+### code chunk number 26: SDEs.Rnw:510-513
 ###################################################
 mu = .2
-mod2d <- snssde2d(driftx=fx,diffx=gx,drifty=fy,diffy=gy,N=10000,Dt=0.01,type="str")
-plot2d(mod2d,type="l")
+mod2d <- snssde2d(driftx=fx,diffx=gx,drifty=fy,diffy=gy,type="str",T=100,,N=10000)
+plot2d(mod2d)
 
 
 ###################################################
-### code chunk number 27: SDEs.Rnw:547-548
+### code chunk number 27: SDEs.Rnw:515-516
 ###################################################
-plot(mod2d)
+plot(mod2d,pos=3)
 
 
 ###################################################
-### code chunk number 28: SDEs.Rnw:636-646
+### code chunk number 28: SDEs.Rnw:604-614
 ###################################################
 K = 4; s = 1; sigma = 0.2
 fx <- expression( (-K*x/sqrt(x^2+y^2+z^2)) )
@@ -246,26 +241,26 @@ mod3d
 
 
 ###################################################
-### code chunk number 29: SDEs.Rnw:651-653 (eval = FALSE)
+### code chunk number 29: SDEs.Rnw:619-621 (eval = FALSE)
 ###################################################
 ## plot3D(mod3d,display="persp",col="blue")  ## in space
-## plot(mod3d,plot.type="signle")            ## with time
+## plot(mod3d,union=TRUE,pos=2)              ## with time
 
 
 ###################################################
-### code chunk number 30: SDEs.Rnw:658-659
+### code chunk number 30: SDEs.Rnw:626-627
 ###################################################
 plot3D(mod3d,display="persp",col="blue")
 
 
 ###################################################
-### code chunk number 31: SDEs.Rnw:661-662
+### code chunk number 31: SDEs.Rnw:629-630
 ###################################################
-plot(mod3d,plot.type="signle")
+plot(mod3d,union=TRUE,pos=2)
 
 
 ###################################################
-### code chunk number 32: SDEs.Rnw:701-710
+### code chunk number 32: SDEs.Rnw:669-678
 ###################################################
 fx <- expression((  x - x*y))
 gx <- expression(0.03)
@@ -274,53 +269,51 @@ gy <- expression(0.03)
 fz <- expression(( -z+ y*z ))
 gz <- expression(0.03)
 mod3d <- snssde3d(driftx=fx,diffx=gx,drifty=fy,diffy=gy,driftz=fz,diffz=gz,
-                  N=10000,T=50,x0=0.5,y0=1,z0=2,type="str")
+                  N=10000,T=20,x0=0.5,y0=1,z0=2,type="str")
 mod3d
 
 
 ###################################################
-### code chunk number 33: SDEs.Rnw:713-715 (eval = FALSE)
+### code chunk number 33: SDEs.Rnw:681-683 (eval = FALSE)
 ###################################################
 ## plot3D(mod3d,"persp",col="blue")  ## in space 
-## plot(mod3d,plot.type="signle")    ## with time
+## plot(mod3d,union=TRUE)            ## with time
 
 
 ###################################################
-### code chunk number 34: SDEs.Rnw:720-721
+### code chunk number 34: SDEs.Rnw:688-689
 ###################################################
 plot3D(mod3d,"persp",col="blue")
 
 
 ###################################################
-### code chunk number 35: SDEs.Rnw:723-724
+### code chunk number 35: SDEs.Rnw:691-692
 ###################################################
-plot(mod3d,plot.type="signle")
+plot(mod3d,union=TRUE) 
 
 
 ###################################################
-### code chunk number 36: SDEs.Rnw:744-754
+### code chunk number 36: SDEs.Rnw:712-720
 ###################################################
-mu = 2; sigma=0.2
-fx <- expression(mu*y)
-gx <- expression(sigma*z)
+fx <- expression(2*y)
+gx <- expression(0.2*z)
 fy <- expression(0)
 gy <- expression(1)
 fz <- expression(0)
 gz <- expression(1)
-modtra <- snssde3d(driftx=fx,diffx=gx,drifty=fy,diffy=gy,driftz=fz,diffz=gz,
-                   N=1000)
+modtra <- snssde3d(driftx=fx,diffx=gx,drifty=fy,diffy=gy,driftz=fz,diffz=gz)
 modtra
 
 
 ###################################################
-### code chunk number 37: SDEs.Rnw:757-758 (eval = FALSE)
+### code chunk number 37: SDEs.Rnw:723-724 (eval = FALSE)
 ###################################################
-## plot(modtra$XYZ[,1],ylab="X")
+## plot(modtra$X,plot.type="single",ylab="X")
 
 
 ###################################################
-### code chunk number 38: SDEs.Rnw:763-764
+### code chunk number 38: SDEs.Rnw:729-730
 ###################################################
-plot(modtra$XYZ[,1],ylab="X")
+plot(modtra$X,plot.type="single",ylab="X")
 
 
